﻿using System;
using System.Collections.Generic;
using System.Windows.Forms;

namespace ComboBoxBindingDemo
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            this.bsCustomer.DataSource = this.GetCustomerDataSource();
            this.lblCustomerName.DataBindings.Add("Text", this.bsCustomer, "Name");
            this.lblCountryID.DataBindings.Add("Text", this.bsCustomer, "CountryID");

            //handling this event to update the text manually on ValueChange (due to TextDetached property)
            c1ComboBox1.ValueChanged += C1ComboBox1_ValueChanged;

            //setting the Item Data Binding
            c1ComboBox1.ItemsDataSource = GetDataSource();
            c1ComboBox1.ItemsValueMember = "Id";
            c1ComboBox1.ItemsDisplayMember = "Name";
            c1ComboBox1.TextDetached = true;

            //Set this property for updating DataBinding on ValueChange
            c1ComboBox1.DataBindings.DefaultDataSourceUpdateMode = DataSourceUpdateMode.OnPropertyChanged;
            c1ComboBox1.DataBindings.Add("Value", this.bsCustomer, "CountryID");
        }

        private void C1ComboBox1_ValueChanged(object sender, EventArgs e)
        {
            //If tha Value is not null (being updated by the BindingSource)
            if (c1ComboBox1.Value != null)
            {
                //Get the Value (Country.Id)
                if (int.TryParse(c1ComboBox1.Value.ToString(), out int _value))
                {
                    //Get the corresponding DataObject
                    var dataObject = (c1ComboBox1.ItemsDataSource as List<Country>).Find(x => x.Id == _value);

                    //If found, update the Text with the Country Name
                    if (dataObject != null)
                    {
                        c1ComboBox1.Text = dataObject.Name;
                    }
                }   
            }
        }

        /// <summary>
        /// Returns Sample Data For the C1ComboBox
        /// </summary
        private List<Country> GetDataSource()
        {
            List<Country> list = new List<Country>
            {
                new Country() { Id = 1, Name = "United States" },
                new Country() { Id = 2, Name = "China" },
                new Country() { Id = 3, Name = "Japan" },
                new Country() { Id = 4, Name = "Germany" },
                new Country() { Id = 5, Name = "India" }
            };

            return list;
        }

        /// <summary>
        /// Returns Sample Data For the C1ComboBox
        /// </summary
        private List<Customer> GetCustomerDataSource()
        {
            List<Customer> list = new List<Customer>
            {
                new Customer() { Name = "John", CountryID = 1 },
                new Customer() { Name = "Bebe", CountryID = 2 },
                new Customer() { Name = "Isabella", CountryID = 4 }
            };

            return list;
        }
    }

    /// <summary>
    /// Represents an item of the C1ComboBox
    /// </summary>
    public class Country
    {
        public string Name { get; set; }

        public int Id { get; set; }
    }

    /// <summary>
    /// Represents an item of the C1ComboBox
    /// </summary>
    public class Customer
    {
        public string Name { get; set; }

        public int CountryID { get; set; }
    }
}
